@@ -40,6 +40,10 @@ arrXscale=[1, 4, 6] #scaling steps X accis
 arrXscaleLen=3
 Xscale=1 #default value X scale in arraXscale index
 
+derivation_offset=2
+
+Yscale_sleep=1
+
 Value_index=0
 Values_total=0
 
@@ -128,7 +132,6 @@ arrFilter=[0, 5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65, 70, 75, 80, 85,
 
 #arrDataFiltered=[[0]*MaxArrayDataLen]
 FilterShift= 30 #Sync point with movement derivation
-FilterScale=1800
-
+filterScale=40
 
 
