@@ -246,7 +246,7 @@ def LoadRecord():
         print "Record header successful read"
     except:
         print "Record header data corrupt"
-        records.status="File header corrupted or not compatible"
+        records.status=_("File header corrupted or not compatible")
         records.statusID="HEADER_CORRUPTED"
 #        print sys.exc_info()
         file.close()
@@ -265,27 +265,29 @@ def LoadRecord():
             records.arrData[2][records.Index]=int(d[2]) #Y
             if(records.SWversion<1.8): #workaround for old files (versions <1.8 had only X and Y axis stored)
                 records.arrData[3][records.Index]=0 #Z
-                records.arrData[5][records.Index]=d[3] #Event
+                try:
+                    records.arrData[5][records.Index]=d[3] #Event
+                except:
+                    pass
             else:
                 records.arrData[3][records.Index]=int(d[3]) #Z
-                records.arrData[5][records.Index]=d[4] #Event
+                try:
+                    records.arrData[5][records.Index]=d[4] #Event
+                except:
+                    pass
 
-#            try:
-#                records.arrData[5][records.Index]=d[3] #Event
-#            except:
-#                pass
-    #
             records.Index=records.Index+1
             if(records.Index==records.MaxArrayDataLen-1):
                 print "Stopped, array is full, file is to big. Loaded ",  records.Index,  "lines"
-                records.status="Data Array is full (max "+str(records.MaxArrayDataLen)+ " entries)"
+    #                records.status="Data Array is full (max "+str(records.MaxArrayDataLen)+ " entries)"
+                records.status="Data array is full"
                 records.statusID="ARRAY_FULL"
     #                file.close()
     #                return 7 #File to long
                 break
     except:
         print "File is corrupted"
-        records.status="File is corrupted or not compatible"
+        records.status=_("File is corrupted or not compatible")
         records.statusID="FILE_CORRUPTED"
         file.close()
         return 3 #corrupted file
@@ -294,7 +296,7 @@ def LoadRecord():
 
     if(records.Index==0):
         print "No movement data in record"
-        records.status="No movement data in file to be shown"
+        records.status=_("No movement data in file to be shown")
         records.statusID="NO_DATA"
         return 4
 
@@ -314,7 +316,7 @@ def LoadRecord():
         if(data.debug==1): print "But will show up to index",  records.LastIndex,  "as the AlarmTimeWindow ends there"
     else: records.LastIndex=records.Index
 
-    records.status="Data successful loaded"
+    records.status=_("Data successful loaded")
     records.statusID="OK"
 
     if(data.debug==1): PrintRecordData(False)
