@@ -45,63 +45,128 @@ def LoadConfig():
     config = ConfigParser.SafeConfigParser()
     try:
         config.read(data.configfolder+data.ConfigFile)
+    except: #use default config
+        print "Configuration file "+data.configfolder+data.ConfigFile + " not existing or not compatible"
 
+    try:
+        config.add_section('main')
+    except:
+        pass
+
+    try:
         data.Sampling_interval = config.getint('main', 'sampling')
+    except:
+        config.set('main', 'sampling', str(data.Sampling_interval))
+
+    try:
         data.Sample_smoothing = config.getint('main', 'sample_smoothing')
+    except:
+        config.set('main', 'sample_smoothing', str(data.Sample_smoothing))
+
+    try:
         data.Value_smoothing = config.getint('main', 'value_smoothing')
+    except:
+        config.set('main', 'value_smoothing', str(data.Value_smoothing))
+
+    try:
         data.Trigger = config.getint('main', 'Trigger')
+    except:
+        config.set('main', 'Trigger', str(data.Trigger))
+
+    try:
         data.Derivation = config.getint('main', 'Derivation')
+    except:
+        config.set('main', 'Derivation', str(data.Derivation))
+
+    try:
         data.Ysize = config.getint('main', 'Ysize')
+    except:
+        config.set('main', 'Ysize', str(data.Ysize))
+
+    try:
         data.Xscale = config.getint('main', 'Xscale')
+    except:
+        config.set('main', 'Xscale', str(data.Xscale))
+
+    try:
         data.Yscale = config.getint('main', 'Yscale')
+    except:
+        config.set('main', 'Yscale', str(data.Yscale))
+
+    try:
+        data.derivation_offset = config.getint('main', 'derivation_offset')
+    except:
+        config.set('main', 'derivation_offset', str(data.derivation_offset))
+
+    try:
+        data.filterScale = config.getint('main', 'filterScale')
+    except:
+        config.set('main', 'filterScale', str(data.filterScale))
+
+    try:
         tmp=config.get('main', 'user')
         data.user = tmp.decode("utf-8")
+    except:
+        config.set('main', 'user', str(data.user.encode( "utf-8" )))
+
+    try:
         data.lastlogfile = config.get('main', 'lastlogfile')
+    except:
+        config.set('main', 'lastlogfile', str(data.lastlogfile))
+
+    try:
         tmp = config.get('main', 'OfflineMode')
         if(tmp=="True"): data.OfflineMode=True
         else: data.OfflineMode=False
+    except:
+        config.set('main', 'OfflineMode', str(data.OfflineMode))
+
+    try:
         tmp = config.get('main', 'SilentProfile')
         if(tmp=="True"): data.SilentProfile=True
         else: data.SilentProfile=False
+    except:
+        config.set('main', 'SilentProfile', str(data.SilentProfile))
+
+    try:
         data.DelayStartTime = config.getint('main', 'DelayStartTime')
+    except:
+        config.set('main', 'DelayStartTime', str(data.DelayStartTime))
+
+    try:
         data.AlarmHour = config.getint('main', 'AlarmHour')
+    except:
+        config.set('main', 'AlarmHour', str(data.AlarmHour))
+
+    try:
         data.AlarmMinute = config.getint('main', 'AlarmMinute')
+    except:
+        config.set('main', 'AlarmMinute', str(data.AlarmMinute))
+
+    try:
         data.AlarmTimeWindow = config.getint('main', 'AlarmTimeWindow')
+    except:
+        config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))
+
+    try:
         tmp = config.get('main', 'StopAfterAlarm')
         if(tmp=="True"): data.StopAfterAlarm=True
         else: data.StopAfterAlarm=False
-        print "Configuration successful loaded from "+data.ConfigFile
-
-    except: #use default config
-        print "Configuration file "+data.configfolder+data.ConfigFile + " not existing or not compatible"
-        try:
-            config.add_section('main')
-        except:
-            pass
-        config.set('main', 'sampling', str(data.Sampling_interval))
-        config.set('main', 'sample_smoothing', str(data.Sample_smoothing))
-        config.set('main', 'value_smoothing', str(data.Value_smoothing))
-        config.set('main', 'Trigger', str(data.Trigger))
-        config.set('main', 'Derivation', str(data.Derivation))
-        config.set('main', 'Ysize', str(data.Ysize))
-        config.set('main', 'Xscale', str(data.Xscale))
-        config.set('main', 'Yscale', str(data.Yscale))
-        config.set('main', 'user', str(data.user.encode( "utf-8" )))
-        config.set('main', 'lastlogfile', str(data.lastlogfile))
-        config.set('main', 'OfflineMode', str(data.OfflineMode))
-        config.set('main', 'SilentProfile', str(data.SilentProfile))
-        config.set('main', 'DelayStartTime', str(data.DelayStartTime))
-        config.set('main', 'AlarmHour', str(data.AlarmHour))
-        config.set('main', 'AlarmMinute', str(data.AlarmMinute))
-        config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))
+    except:
         config.set('main', 'StopAfterAlarm', str(data.StopAfterAlarm))
-        print "Loaded default parameters"
+
+    print "Configuration successful loaded from "+data.ConfigFile
+
     return config
 
 
 
 
 
+
+
+
+
 ###########################################################################
 ## Write the configuration into the config file
 ###########################################################################
