@@ -15,9 +15,9 @@ __ss_bool IsCompiled() {
     return r;
 }
 
-list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift) {
+list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *filter, __ss_int shift, __ss_int scale) {
     list<__ss_int> *ar_ret;
-    __ss_int __0, __1, __2, __3, i, len_filter, p, value;
+    __ss_int __0, __1, __2, __3, __4, __5, i, len_filter, p, value;
 
     len_filter = len(filter);
     ar_ret = ((new list<__ss_int>(1, 0)))->__mul__((l+len_filter));
@@ -31,6 +31,11 @@ list<__ss_int> *sleep_filter(list<__ss_int> *ar, __ss_int l, list<__ss_int> *fil
 
     END_FOR
 
+
+    FAST_FOR(i,0,(l-1),1,4,5)
+        ar_ret->__setitem__(i, __divs(ar_ret->__getfast__(i), (scale*100)));
+    END_FOR
+
     return ar_ret;
 }
 
@@ -43,7 +48,7 @@ void __init() {
         IsCompiled();
         arTest = (new list<__ss_int>(9, 1, 2, 3, 4, 5, 6, 7, 8, 9));
         arFiltertest = (new list<__ss_int>(3, 1, 2, 3));
-        sleep_filter(arTest, 1, arFiltertest, 1);
+        sleep_filter(arTest, 1, arFiltertest, 1, 20);
     }
 }
 
@@ -75,8 +80,9 @@ PyObject *Global_mylib_sleep_filter(PyObject *self, PyObject *args, PyObject *kw
         __ss_int arg_1 = __ss_arg<__ss_int >("l", 1, 0, NULL, args, kwargs);
         list<__ss_int> *arg_2 = __ss_arg<list<__ss_int> *>("filter", 2, 0, NULL, args, kwargs);
         __ss_int arg_3 = __ss_arg<__ss_int >("shift", 3, 0, NULL, args, kwargs);
+        __ss_int arg_4 = __ss_arg<__ss_int >("scale", 4, 0, NULL, args, kwargs);
 
-        return __to_py(__mylib__::sleep_filter(arg_0, arg_1, arg_2, arg_3));
+        return __to_py(__mylib__::sleep_filter(arg_0, arg_1, arg_2, arg_3, arg_4));
 
     } catch (Exception *e) {
         PyErr_SetString(__to_py(e), ((e->msg)?(e->msg->unit.c_str()):""));
