@@ -18,17 +18,20 @@ def IsCompiled():
 
 
 
-def sleep_filter(ar, l, filter,  shift):
+def sleep_filter(ar, l, filter,  shift, scale):
     len_filter=len(filter)
-    
+
     ar_ret=[0]*(l+len_filter)
 
     for i in range(0, l-1): #loop arrData
         value=ar[i]
-       
+
         for p in range(0,  len_filter-1): #loop arrFilter
             ar_ret[i+p-shift] = ar_ret[i+p-shift] + value*filter[p]
 
+    for i in range(0, l-1): #loop arrData
+        ar_ret[i]=ar_ret[i]/(scale*100)
+
     return ar_ret
 
 
@@ -37,7 +40,7 @@ def sleep_filter(ar, l, filter,  shift):
 
 if __name__ == '__main__':
     #those lines are needed, so Shedskin knows how the parameters of the functions are:
-    IsCompiled()    
+    IsCompiled()
     arTest=[1, 2, 3, 4, 5, 6, 7, 8, 9]
     arFiltertest=[1, 2, 3]
-    sleep_filter(arTest, 1, arFiltertest, 1)
+    sleep_filter(arTest, 1, arFiltertest, 1, 20)
