@@ -288,9 +288,22 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #        print "Alarm is active"
         if(data.StopAfterAlarm==True):
 #            print "Stop measurement, alarm is active"
-            data.Status=_("Alarm got activated, stopped recording")
+            txt=_("Alarm got activated, stopped recording")
+            print txt
+            data.Status=txt
             StopMeasurement() #stop but keep alarm active!
 
+            #change directly to view screen
+#            DeleteAlarm() #delete Alarm if existing
+#            records.AlarmIsSet=False
+            data.lastlogfile=data.logfilename #set to corrent file for viewwindow
+            config.set('main', 'lastlogfile', str(data.lastlogfile))
+            print "Show record in ViewWindow:",  data.lastlogfile
+            StartWindow.ShowViewWindow()
+            RecordWindow.hide()
+
+
+
 
 
 ###########################################################################
@@ -407,7 +420,6 @@ def StopMeasurement():
     GenerateStatisticData()
     GenerateGraphBitmap(RecordWindow, False)
 
-    RecordWindow.UpdateScreenStop()
     RecordWindow.Canvas.update()
     RecordWindow.UpdateScreen()
     app.processEvents() #force ui update
@@ -445,6 +457,10 @@ def StopMeasurement():
                     pass
 
 
+    RecordWindow.UpdateScreenStop()
+
+
+
 
 
 
@@ -827,9 +843,6 @@ class frmRecordWindow(QMainWindow):
 
 
 
-
-
-
     def StopMeasurement(self): ##(Class RecordWindow)
             self.closeEvent(0)
 
@@ -1001,6 +1014,12 @@ class frmViewWindow(QMainWindow):
 
 
         self.setWindowTitle("SleepAnalyser ("+_("View")+")")
+        self.ui.lblstate1.setText(_("Awake"))
+        self.ui.lblstate2.setText(_("Light sleep"))
+        self.ui.lblstate3.setText(_("Deep sleep"))
+
+
+
 
 
     def UpdateScreen(self): ##(Class ViewWindow)
@@ -1015,9 +1034,11 @@ class frmViewWindow(QMainWindow):
 ##        The following lines are disabled, currently i dont care if it could record for more than 24h
 #        if(diff_sec>86400): d="1 day, " #longer than 24h
 #        else: d=""
+#        print day
         self.ui.lblStart.setText(str(day))
 #        self.ui.lblEnd.setText(str(d1)+" (Duration: "+d+str(diff)+")")
-        self.ui.lblEnd.setText(_("Start:")+" "+d0+", "+_("End:")+" "+d1+", "+_("Duration:")+" "+diff)
+#        self.ui.lblEnd.setText(_("Start:")+" "+d0+", "+_("End:")+" "+d1+", "+_("Duration:")+" "+diff)
+#        print d0+" - "+d1+"   ("+diff+")"
         self.ui.lblEnd.setText(d0+" - "+d1+"   ("+diff+")")
 
 #        self.ui.lblNote.setText("Note: "+records.Note)
@@ -1084,6 +1105,11 @@ class frmViewWindow(QMainWindow):
 #            QtGui.QMessageBox.warning(self, 'File version too old!', "Can not load record \n"+data.logfilename+"\nas it got created from SleepAnalyser version <1.6 and is not compatible with the current SleepAnalyser version.", QtGui.QMessageBox.Ok)
 #        LoadFileList()
 
+
+        self.UpdateScreen()
+        app.processEvents() #force ui update
+
+
         self.ui.lblStatus.setText(_("Processessing data..."))
         app.processEvents() #force ui update
         ProcessData(True, True)
@@ -1110,14 +1136,11 @@ class frmViewWindow(QMainWindow):
         GenerateGraphBitmap(self, True)
         GenerateStatisticsBitmap(self)
 
+    #Note: On the PC, the lable texts disappears here again until the window looses the focus, but it works fine on the N900, so I ignore it
 
 
 
 
-#    def ApplyFilter(self): ##(Class ViewWindow)
-
-
-
     ###########################################################################
     ##
     ###########################################################################
@@ -1693,7 +1716,7 @@ class frmAdditionalInfoWindow(QMainWindow):
         "<b>"+_("Record version:")+"</b> "+str(records.SWversion) + "<br>" + \
         alarm +\
         "<b>"+_("Trigger level:")+"</b> "+str(records.Trigger) + "<br>" + \
-        "<b>"+_("Condition of record:")+"</b> "+str(records.status)+"<br><br>"
+        "<b>"+_("Condition of record:")+"</b> "+str(records.status)
 #        "<b>"+_("User:")+"</b> "+str(records.User) +"<br>" + \ ##Disabled due charset errors
 #        "<b>"+_("Note:")+"</b> "+str(records.Note)+"<br>" +\ ##Disabled due charset errors
 
@@ -1708,14 +1731,16 @@ class frmAdditionalInfoWindow(QMainWindow):
 ##        pd=records.arrStatData[3][0]*100/t_total
 #        pl=100-pa-pb-pc
 
+        txt=txt+"<hr>"
         txt=txt+"<b>"+_("Statistics:")+"</b><table>\n" + \
-                "<tr><td><b>"+_("Sleep phase:")+" </b></td>   <td><b>"+_("Total time:")+" </b></td>                                     <td><b>"+_("Longest time:")+"</b></td>                                    <td><b>"+_("Count:")+" </b></td>                     <td colspan=2><b>"+_("Time percent:")+"</b></td>\n" + \
-                "<tr><td><b>"+_("Awake:")+"</b></td>         <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>"+_("Light:")+"</b></td>         <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>"+_("Middle:")+"</b></td>        <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
-                "<tr><td><b>"+_("Deep:")+"</b></td>          <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime("%H:%M:%S", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
-              "</table><br><br>\n"
+                "<tr bgcolor=#DCDCDC><td><b>"+_("Time without<br>movement:")+" </b></td>   <td><b>"+_("Total:")+" </b></td>                                     <td><b>"+_("Maximum:")+"</b></td>                                    <td><b>"+_("Count:")+" </b></td>                     <td colspan=2><b>"+_("Time percent:")+"</b></td>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+_("&gt; 7 minutes:")+"</b></td>         <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[3][0]))+"</td>    <td>-</td>    <td>-</td>    <td>"+str(records.arrStatData[3][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State4.png"+"\" width="+str(records.arrStatData[3][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+_("&lt; 7 minutes:")+"</b></td>         <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[2][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[2][2]))+"</td>    <td>"+str(records.arrStatData[2][1])+"</td>    <td>"+str(records.arrStatData[2][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State3.png"+"\" width="+str(records.arrStatData[2][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+_("&lt; 15 minutes:")+"</b></td>        <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[1][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[1][2]))+"</td>    <td>"+str(records.arrStatData[1][1])+"</td>    <td>"+str(records.arrStatData[1][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State2.png"+"\" width="+str(records.arrStatData[1][3]*2)+" height=25</td></tr>\n" + \
+                "<tr><td bgcolor=#DCDCDC><b>"+_("&lt; 30 minutes:")+"</b></td>        <td>"+strftime("%Hh %Mm ", time.gmtime(records.arrStatData[0][0]))+"</td>    <td>"+strftime(" %Hh %Mm ", time.gmtime(records.arrStatData[0][2]))+"</td>    <td>"+str(records.arrStatData[0][1])+"</td>    <td>"+str(records.arrStatData[0][3])+"%</td><td><img src=\""+data.app_path+"img/"+"State1.png"+"\" width="+str(records.arrStatData[0][3]*2)+" height=25</td></tr>\n" + \
+              "</table>\n"
 
+        txt=txt+"<hr>"
         txt=txt+"<b>"+_("Sampling interval:")+"</b> "+str(records.Sampling_interval) + " ms<br>" + \
         "<b>"+_("Sampling smoothing:")+"</b> "+str(records.Sample_smoothing) + "<br>" + \
         "<b>"+_("Value smoothing:")+"</b> "+str(records.Value_smoothing)
@@ -1905,11 +1930,10 @@ class frmAskForKeepWindow(QMainWindow):
         records.AlarmIsSet=False
         data.lastlogfile=data.logfilename #set to corrent file for viewwindow
         config.set('main', 'lastlogfile', str(data.lastlogfile))
-#        RecordWindow.hide()
         print "Show record in ViewWindow:",  data.lastlogfile
-        StartWindow.ShowViewWindow()
         RecordWindow.hide()
         self.hide()
+        StartWindow.ShowViewWindow()
 
 
 
@@ -1918,7 +1942,7 @@ class frmAskForKeepWindow(QMainWindow):
     ###########################################################################
     def RemoveRecord(self): ##(Class AskForKeepWindow)
         print "Stop recording and remove record"
-        global StartWindow,  RecordWindow
+#        global StartWindow,  RecordWindow
         StopMeasurement()
         DeleteAlarm() #delete Alarm if existing
         records.AlarmIsSet=False
